/*
 * app_data.h,
 *
 * Copyright (C) 1997 Rasca Gmelch, Berlin
 * Copyright (C) 2003-2004 Karl H. Beckers, Frankfurt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __APP_DATA_H__
#define __APP_DATA_H__

/* 
 * some flags to toggle on/off options
 *
 */
#define FLG_NONE                        0
#define FLG_MNG_CLONE                   1
#define FLG_RUN_VERBOSE                 2
#define FLG_EXPAND_TO_24BIT             4
#define FLG_MULTI_IMAGE                 8
#define FLG_USE_SHM                     16
#define FLG_USE_DGA                     32
#define FLG_USE_V4L                     64
#define FLG_SOURCE                      (FLG_USE_DGA | FLG_USE_SHM | FLG_USE_V4L)
#define FLG_REC_SND                     128 // not used atm ... using flg_audio_wanted, forgot this one
#define FLG_SYNC                        256
#define FLG_NOGUI                       512
#define FLG_AUDIO_WANTED                1024
#define FLG_AUTO_CONTINUE               2048

/* 
 * moving AppData definition here to make it available to options.c, control.c etc.
 *
 * this structure is used to pass options passed to the application to the job
 * controller
 */
typedef struct {
    float fps;          // frames per second
    char *file;         // file pattern
    int targetCodec;    // for video encoding
    int verbose;        // verbose level
    int flags;          // flags used ... see above
    int cap_width;      // width
    int cap_height;     // height
    int cap_pos_x;      // x position of the capture frame
    int cap_pos_y;      // y position of the capture frame
    float time;         // time in seconds to record
    int frames;         // max frames to record
    int start_no;       // frame number to start with
    int step;           // frame increment
    int compress;       // compression rate
    int quality;        // quality setting
    int bpp;            // bits per pixel
    int mouseWanted;    // capture mouse pointer: 0 none , 1 white , 2 black
    char *source;       // video capture source
    char *snddev;       // audio capture source
    int sndrate;        // sound sample rate
    int sndsize;        // bits to sample for audio capture
    int sndchannels;    // number of channels to record audio to 
    char *play_cmd;     // command to use for animate function
    char *video_cmd;    // command to use for make video function
    char *edit_cmd;     // command to use for edit function
    char *help_cmd;     // command to use for displaying help information
    char *device;       // v4l device to capture from
    Boolean use_clone;  // use clone setting
} AppData;

#endif //__APP_DATA_H__
